@@ -1,8 +1,4 @@
-#ifndef __GDICT_SPELLER_H_
-#define __GDICT_SPELLER_H_
-
-/* $Id: gdict-speller.h,v 1.13 2004/12/23 18:43:42 vnoel Exp $ */
-
+/* $Id: gdict-speller.h,v 1.14 2005/06/15 18:54:40 vnoel Exp $ */
 /*
  *  Mike Hughes <mfh@psilord.com>
  *  Papadimitriou Spiros <spapadim@cs.cmu.edu>
@@ -15,6 +11,11 @@
  *
  */
 
+#ifndef GDICT_SPELLER_H
+#define GDICT_SPELLER_H
+
+G_BEGIN_DECLS
+
 #include <gtk/gtk.h>
 #include "dict.h"
 #include "gdict-app.h"
@@ -26,21 +27,18 @@
 #define GDICT_IS_SPELLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GDICT_TYPE_SPELLER))
 #define GDICT_SPELLER_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GDICT_TYPE_SPELLER, GDictSpellerClass))
 
-
 typedef struct _GDictSpeller        GDictSpeller;
 typedef struct _GDictSpellerClass   GDictSpellerClass;
 
 struct _GDictSpeller {
     GtkVBox      vbox;
-    
+    GtkWidget      *hbox;
+    GtkWidget	   *word_list;
+
     dict_context_t *context;
     dict_command_t *spell_cmd;
     gchar          *database;
     gchar          *strat;
-    
-    GtkWidget      *hbox;
-    GtkWidget	   *word_list;
-    
     gchar          *current_word;
 
     GDictWindow    *gdict;
@@ -64,4 +62,6 @@ void       gdict_speller_reset_strat (GDictWindow *gdict, GDictSpeller *speller)
 void       gdict_speller_change_strategy (GDictSpeller *speller, gchar *new_strategy);
 void       gdict_speller_change_db (GDictSpeller *speller, gchar *new_db);
 
-#endif /* __GDICT_SPELLER_H_ */
+G_END_DECLS
+
+#endif /* GDICT_SPELLER_H */
