@@ -48,16 +48,21 @@
 
 #define SILENT_WINDOW_OPEN_LIMIT 5
 
+#ifdef HAVE_GETPGID
+extern pid_t getpgid (pid_t);
+#endif
+
 gboolean row_selected_by_button_press_event;
 
 static void
 quit_application (GSearchCommandDetails * command_details)
 {
 	if (command_details->command_status == RUNNING) {
-		command_details->command_status = MAKE_IT_QUIT;
 #ifdef HAVE_GETPGID
 		pid_t pgid;
-		
+#endif
+		command_details->command_status = MAKE_IT_QUIT;
+#ifdef HAVE_GETPGID
 		pgid = getpgid (command_details->command_pid);
 		
 		if ((pgid > 1) && (pgid != getpid ())) {
@@ -110,8 +115,10 @@ click_find_cb (GtkWidget * widget,
 	if ((gsearch->command_details->command_status == STOPPED) ||
 	    (gsearch->command_details->command_status == ABORTED)) {
 	    	command = build_search_command (gsearch, TRUE);
-		spawn_search_command (gsearch, command);
-		g_free (command);
+		if (command != NULL) {
+			spawn_search_command (gsearch, command);
+			g_free (command);
+		}
 	}
 }
 
@@ -122,11 +129,12 @@ click_stop_cb (GtkWidget * widget,
 	GSearchWindow * gsearch = data;
 
 	if (gsearch->command_details->command_status == RUNNING) {
+#ifdef HAVE_GETPGID
+		pid_t pgid;
+#endif
 		gtk_widget_set_sensitive (gsearch->stop_button, FALSE);
 		gsearch->command_details->command_status = MAKE_IT_STOP;
 #ifdef HAVE_GETPGID
-		pid_t pgid;
-		
 		pgid = getpgid (gsearch->command_details->command_pid);
 		
 		if ((pgid > 1) && (pgid != getpid ())) {
@@ -360,6 +368,35 @@ display_dialog_could_not_open_file (GtkWidget * window,
 	g_free (primary);
 }
 
+static void
+display_dialog_could_not_open_folder (GtkWidget * window,
+                                      const gchar * folder)
+{ 		
+	GtkWidget * dialog;
+	gchar * primary;
+
+	primary = g_strdup_printf (_("Could not open folder \"%s\"."), folder);
+
+	dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+	                                 GTK_DIALOG_DESTROY_WITH_PARENT,
+	                                 GTK_MESSAGE_ERROR,
+	                                 GTK_BUTTONS_OK,
+	                                 primary);
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+	                                          _("The nautilus file manager is not running."));
+
+	gtk_window_set_title (GTK_WINDOW (dialog), "");
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
+
+	g_signal_connect (G_OBJECT (dialog),
+               		  "response",
+               		  G_CALLBACK (gtk_widget_destroy), NULL);
+
+	gtk_widget_show (dialog);			
+	g_free (primary);
+}
+
 void
 open_file_cb (GtkAction * action,
               gpointer data)
@@ -420,10 +457,12 @@ open_file_cb (GtkAction * action,
 				
 				if (launch_file (locale_file) == FALSE) {
 					
-					if (is_nautilus_running () &&
-					    g_file_test (locale_file, G_FILE_TEST_IS_DIR)) {
-						open_file_with_nautilus (gsearch->window, locale_file);
-					}
+					if (g_file_test (locale_file, G_FILE_TEST_IS_DIR)) {
+					
+						if (open_file_with_nautilus (gsearch->window, locale_file) == FALSE) {
+							display_dialog_could_not_open_folder (gsearch->window, utf8_name);
+						}
+					} 
 					else {
 						display_dialog_could_not_open_file (gsearch->window, utf8_name, 
 						                                    _("There is no installed viewer capable "
@@ -486,35 +525,6 @@ display_dialog_folder_open_limit (GtkWidget * window,
 
 	return response;
 }
-
-static void
-display_dialog_could_not_open_folder (GtkWidget * window,
-                                      const gchar * folder)
-{ 		
-	GtkWidget * dialog;
-	gchar * primary;
-
-	primary = g_strdup_printf (_("Could not open folder \"%s\"."), folder);
-
-	dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-	                                 GTK_DIALOG_DESTROY_WITH_PARENT,
-	                                 GTK_MESSAGE_ERROR,
-	                                 GTK_BUTTONS_OK,
-	                                 primary);
-	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-	                                          _("The nautilus file manager is not running."));
-
-	gtk_window_set_title (GTK_WINDOW (dialog), "");
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
-
-	g_signal_connect (G_OBJECT (dialog),
-               		  "response",
-               		  G_CALLBACK (gtk_widget_destroy), NULL);
-
-	gtk_widget_show (dialog);			
-	g_free (primary);
-}
 	
 void
 open_folder_cb (GtkAction * action,
@@ -557,10 +567,8 @@ open_folder_cb (GtkAction * action,
 			    							
 		folder_locale = g_filename_from_utf8 (folder_utf8, -1, NULL, NULL, NULL);
 		
-		if (is_nautilus_running ()) {
-			open_file_with_nautilus (gsearch->window, folder_locale);
-		}
-		else {
+		if (open_file_with_nautilus (gsearch->window, folder_locale) == FALSE) {
+		
 			display_dialog_could_not_open_folder (gsearch->window, folder_utf8);
 			
 			g_list_free (list);
@@ -936,6 +944,13 @@ file_button_release_event_cb (GtkWidget * widget,
 		}
 		g_list_free (list);
 	}
+	else if (event->button == 1 || event->button == 2) {
+		if (gsearch->is_search_results_single_click_to_activate == TRUE) {
+			if (!(event->state & GDK_CONTROL_MASK) && !(event->state & GDK_SHIFT_MASK)) {
+			     	open_file_cb ((GtkAction *) NULL, data);
+			}
+		}
+	}
 	return FALSE;
 }
 
@@ -955,21 +970,101 @@ file_event_after_cb  (GtkWidget * widget,
 	}
 
 	if (!(event->state & GDK_CONTROL_MASK) && !(event->state & GDK_SHIFT_MASK)) {
-		if (gsearch->is_search_results_single_click_to_activate == TRUE) {
-			if ((event->type == GDK_BUTTON_PRESS)
-			     && (event->button == 1 || event->button == 2)) {
+		if (gsearch->is_search_results_single_click_to_activate == FALSE) {
+			if (event->type == GDK_2BUTTON_PRESS) {
 				open_file_cb ((GtkAction *) NULL, data);
 				return TRUE;
 			}
-		} 
-		else if (event->type == GDK_2BUTTON_PRESS) {
-			open_file_cb ((GtkAction *) NULL, data);
-			return TRUE;
 		}
 	}
 	return FALSE;
 }
 
+gboolean
+file_motion_notify_cb (GtkWidget *widget,
+                       GdkEventMotion *event,
+                       gpointer user_data)
+{
+        GSearchWindow * gsearch = user_data;
+	GdkCursor * cursor;
+	GtkTreePath * last_hover_path;
+	GtkTreeIter iter;
+ 	
+	if (gsearch->is_search_results_single_click_to_activate == FALSE) {
+		gdk_window_set_cursor (event->window, NULL);
+		return FALSE;
+	}
+	
+	if (event->window != gtk_tree_view_get_bin_window (GTK_TREE_VIEW (gsearch->search_results_tree_view))) {
+		gdk_window_set_cursor (event->window, NULL);
+                return FALSE;
+	}
+	
+	last_hover_path = gsearch->search_results_hover_path;
+
+	gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (widget),
+				       event->x, event->y,
+				       &gsearch->search_results_hover_path,
+				       NULL, NULL, NULL);
+
+	if (gsearch->search_results_hover_path != NULL) { 
+		cursor = gdk_cursor_new (GDK_HAND2);
+	}
+	else { 
+		cursor = NULL;
+	}
+	
+	gdk_window_set_cursor (event->window, cursor);
+
+	/* Redraw if the hover row has changed */
+	if (!(last_hover_path == NULL && gsearch->search_results_hover_path == NULL) &&
+	    (!(last_hover_path != NULL && gsearch->search_results_hover_path != NULL) ||
+	     gtk_tree_path_compare (last_hover_path, gsearch->search_results_hover_path))) {
+		if (last_hover_path) {
+			gtk_tree_model_get_iter (GTK_TREE_MODEL (gsearch->search_results_list_store),
+			                         &iter, last_hover_path);
+			gtk_tree_model_row_changed (GTK_TREE_MODEL (gsearch->search_results_list_store),
+			                            last_hover_path, &iter);
+		}
+		
+		if (gsearch->search_results_hover_path) {
+			gtk_tree_model_get_iter (GTK_TREE_MODEL (gsearch->search_results_list_store),
+			                         &iter, gsearch->search_results_hover_path);
+			gtk_tree_model_row_changed (GTK_TREE_MODEL (gsearch->search_results_list_store),
+			                            gsearch->search_results_hover_path, &iter);
+		}
+	}
+	
+	gtk_tree_path_free (last_hover_path);
+
+ 	return FALSE;
+}
+
+gboolean 
+file_leave_notify_cb (GtkWidget *widget,
+                      GdkEventCrossing *event,
+                      gpointer user_data)
+{
+        GSearchWindow * gsearch = user_data;
+	GtkTreeIter iter;
+
+	if (gsearch->is_search_results_single_click_to_activate && (gsearch->search_results_hover_path != NULL)) {
+		gtk_tree_model_get_iter (GTK_TREE_MODEL (gsearch->search_results_list_store),
+		                         &iter, 
+		                         gsearch->search_results_hover_path);
+		gtk_tree_model_row_changed (GTK_TREE_MODEL (gsearch->search_results_list_store),
+		                            gsearch->search_results_hover_path,
+		                            &iter);
+
+		gtk_tree_path_free (gsearch->search_results_hover_path);
+		gsearch->search_results_hover_path = NULL;
+
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
 void  
 drag_begin_file_cb (GtkWidget * widget,
                     GdkDragContext * context,
@@ -1059,7 +1154,7 @@ drag_file_cb  (GtkWidget * widget,
 			gtk_selection_data_set (selection_data,
 			                        selection_data->target,
 			                        8,
-			                        uri_list,
+			                        (guchar *) uri_list,
 			                        strlen (uri_list));
 			g_free (tmp_uri);
 		}
@@ -1134,7 +1229,7 @@ drag_data_animation_cb (GtkWidget * widget,
 	if (gnome_desktop_item_save (ditem, NULL, FALSE, NULL)) {
 		gtk_selection_data_set (selection_data,
 					selection_data->target, 8,
-					uri, strlen (uri));
+					(guchar *) uri, strlen (uri));
 	}
 	gnome_desktop_item_unref (ditem);
 
@@ -1158,6 +1253,9 @@ show_file_selector_cb (GtkAction * action,
 	                                            GTK_STOCK_SAVE, GTK_RESPONSE_OK,
 	                                            NULL);
 
+#if GTK_CHECK_VERSION(2,7,3)
+	gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (file_chooser), TRUE);
+#endif
 	if (gsearch->save_results_as_default_filename != NULL) {
 		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (file_chooser),
 		                               gsearch->save_results_as_default_filename);
@@ -1233,6 +1331,7 @@ display_dialog_could_not_save_to (GtkWidget * window,
 	g_free (primary);
 }
 
+#if !GTK_CHECK_VERSION(2,7,3)
 static gint
 display_dialog_could_not_save_exists (GtkWidget * window,
                                       const gchar * file)
@@ -1277,6 +1376,7 @@ display_dialog_could_not_save_exists (GtkWidget * window,
 
 	return response;
 }
+#endif
 
 void
 save_results_cb (GtkWidget * chooser,
@@ -1316,6 +1416,7 @@ save_results_cb (GtkWidget * chooser,
 		return;	
 	}
 	
+#if !GTK_CHECK_VERSION(2,7,3)	
 	if (g_file_test (gsearch->save_results_as_default_filename, G_FILE_TEST_EXISTS)) {
 
 		gint response;
@@ -1327,6 +1428,7 @@ save_results_cb (GtkWidget * chooser,
 			return;
 		}
 	}
+#endif	
 
 	if ((fp = fopen (gsearch->save_results_as_default_filename, "w")) != NULL) {
 
@@ -1380,7 +1482,7 @@ save_session_cb (GnomeClient * client,
 	char ** argv;
 	int argc;
 
-	set_clone_command (gsearch, &argc, &argv, client_data, FALSE);
+	set_clone_command (gsearch, &argc, &argv, "gnome-search-tool", FALSE);
 	gnome_client_set_clone_command (client, argc, argv);
 	gnome_client_set_restart_command (client, argc, argv);	
 }
@@ -1452,3 +1554,19 @@ disable_quick_search_cb (GtkWidget * dialog,
 	}
 }
 
+void
+single_click_to_activate_key_changed_cb (GConfClient * client, 
+                                         guint cnxn_id,
+                                         GConfEntry * entry,
+                                         gpointer user_data)
+{
+	GSearchWindow * gsearch = user_data;
+	GConfValue * value;
+
+	value = gconf_entry_get_value (entry);
+
+	g_return_if_fail (value->type == GCONF_VALUE_STRING);
+
+	gsearch->is_search_results_single_click_to_activate = 
+		(strncmp (gconf_value_get_string (value), "single", 6) == 0) ? TRUE : FALSE;
+}
