@@ -43,12 +43,23 @@ gsearchtool_gconf_get_boolean (const gchar * key);
 void
 gsearchtool_gconf_set_boolean (const gchar * key, 
                                const gboolean flag);
+gint 
+gsearchtool_gconf_get_int (const gchar * key);
+
 char *
 gsearchtool_gconf_get_string (const gchar * key);
 
 GSList * 
 gsearchtool_gconf_get_list (const gchar * key);
 
+void
+gsearchtool_gconf_add_dir (const gchar * dir);
+
+void
+gsearchtool_gconf_watch_key (const gchar * dir,
+                             const gchar * key, 
+                             GConfClientNotifyFunc callback,
+                             gpointer user_data);
 gboolean  	
 is_path_hidden (const gchar * path);
 
@@ -79,13 +90,13 @@ get_readable_date (const gchar * format_string,
 gchar *    	
 gsearchtool_strdup_strftime (const gchar * format, 
                              struct tm * time_pieces); 
-const char *
-get_file_type_for_mime_type (const gchar * file,
-                             const gchar * mime);
+gchar *
+get_file_type_description (const gchar * file,
+                           GnomeVFSFileInfo * file_info);
 GdkPixbuf *
-get_file_pixbuf_for_mime_type (GHashTable * hash,
-                               const gchar * file,
-                               const gchar * mime);
+get_file_pixbuf (GSearchWindow * gsearch,
+                 const gchar * file,
+                 GnomeVFSFileInfo * file_info);
 gboolean 	
 open_file_with_nautilus (GtkWidget * window,
                          const gchar * file);
